@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.028_01';
+our $VERSION = '0.029_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -59,7 +59,7 @@ Or if you prefer L<ExtUtils::MakeMaker>, in its C<Makefile.PL>:
  
  WriteMakefile(
    ...
-   CFLAGS => Alien::MyLibrary->cflags,
+   CCFLAGS => Alien::MyLibrary->cflags,
    LIBS   => ALien::MyLibrary->libs,
    ...
  );
@@ -701,6 +701,10 @@ Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Ba
 
 =item Gianni Ceccarelli (dakkar)
 
+=item Pavel Shaydo (zwon, trinitum)
+
+=item Kang-min Liu (劉康民, gugod)
+
 =back
 
 Thanks also to
